@@ -7,15 +7,15 @@ register = template.Library()
 
 
 @register.filter
-def safe_markdown(field_name):
+def safe_markdown(markdown_text):
     """
-    Safe the markdown text as html ouput.
+    Safe the markdown text as html output.
 
     Usage:
         {% load martortags %}
-        {{ field_name|safe_markdown }}
+        {{ markdown_text|safe_markdown }}
 
     Example:
         {{ post.description|safe_markdown }}
     """
-    return mark_safe(markdownify(field_name))
+    return mark_safe(markdownify(markdown_text))
